@@ -102,6 +102,10 @@ def generated_includes(conf):
             toc_spec_files.append(fn)
         elif base.startswith('steps'):
             step_files.append(fn)
+        elif base.startswith('example'):
+            # example files, for the purpose of this have the same structure as
+            # steps, so we can just use that:
+            step_files.append(fn)
 
     maskl = len(conf.paths.source)
     path_prefix = conf.paths.includes[len(conf.paths.source):]
