@@ -86,25 +86,10 @@ def sphinx_publication(c, args, app):
     ret_code = sum([ o[0] for o in sphinx_app.results ])
     output_sphinx_stream(sphinx_output, c)
 
+    ret_code = 0
+
     return ret_code
 
-def post_build_operations(results, app):
-    logger.info('starting build finalizing')
-
-    sphinx_output = []
-    aggregated_return_code = 0
-
-    for ret_code, ret_sconf, ret_conf, sbuild_output in results:
-        sphinx_output.append(sbuild_output)
-        if ret_code == 0:
-            finalize_sphinx_build(ret_sconf, ret_conf, app)
-        else:
-            aggregated_return_code = 1
-
-    app.run()
-
-    return aggregated_return_code, sphinx_output
-
 def build_prep_tasks(conf, app):
     image_tasks(conf, app)
     robots_txt_tasks(conf, app)
